sphinx_gallery.sorting — Python documentation

# sphinx_gallery.sorting

## Sorters for Sphinx-Gallery (sub)sections

Sorting key functions for gallery subsection folders and section files.

### Classes

class `sphinx_gallery.sorting.` `ExampleTitleSortKey`(src_dir)

  Sort examples in src_dir by example title.

  Parameters

    src_dir (str) – The source directory.

class `sphinx_gallery.sorting.` `ExplicitOrder`(ordered_list)

  Sorting key for all gallery subsections.

  This requires all folders to be listed otherwise an exception is raised.

  Parameters

    ordered_list (list, tuple, or generator) – Hold the paths of each galleries’ subsections.

  Raises

    ValueError – Wrong input type or Subgallery path missing.

#### Examples using `sphinx_gallery.sorting.ExplicitOrder`

Testing future statements across examples

class `sphinx_gallery.sorting.` `FileNameSortKey`(src_dir)

  Sort examples in src_dir by file name.

  Parameters

    src_dir (str) – The source directory.

#### Examples using `sphinx_gallery.sorting.FileNameSortKey`

Link to other packages

class `sphinx_gallery.sorting.` `FileSizeSortKey`(src_dir)

  Sort examples in src_dir by file size.

  Parameters

    src_dir (str) – The source directory.

class `sphinx_gallery.sorting.` `NumberOfCodeLinesSortKey`(src_dir)

  Sort examples in src_dir by the number of code lines.

  Parameters

    src_dir (str) – The source directory.